import { __decorate, __metadata } from 'tslib';
import { Input, Directive, TemplateRef, ViewContainerRef, ContentChildren, QueryList, NgModule } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { NgControl } from '@angular/forms';

var NgxValidatorDirective = /** @class */ (function () {
    function NgxValidatorDirective(template, viewContainer) {
        var _this = this;
        this.template = template;
        this.viewContainer = viewContainer;
        this.visibleSubject = new BehaviorSubject(false);
        this.view = null;
        this.errorParameters = null;
        this.visibleSubject
            .subscribe(function (visibleStatus) {
            if (visibleStatus) {
                _this.destroyView();
                _this.view = _this.viewContainer.createEmbeddedView(_this.template, {
                    params: _this.errorParameters
                });
            }
            else {
                _this.destroyView();
            }
        });
    }
    /**
     * Sets error parameters for the current validator and gives a command to show an error
     * @param error - The parameters given by the validator of reactive forms. Example: Validator.minLength
     *                with parameter 8 will return: "{ requiredLength: 8, actualLength: 2 }"
     */
    NgxValidatorDirective.prototype.showError = function (error) {
        this.errorParameters = error;
        this.visibleSubject.next(true);
    };
    /**
     * Clear error parameters for the current validator and gives a command to hide an error
     */
    NgxValidatorDirective.prototype.hideErrors = function () {
        this.errorParameters = null;
        this.visibleSubject.next(false);
    };
    NgxValidatorDirective.prototype.destroyView = function () {
        if (this.view) {
            this.view.destroy();
        }
    };
    __decorate([
        Input('ngxValidator'),
        __metadata("design:type", String)
    ], NgxValidatorDirective.prototype, "validator", void 0);
    NgxValidatorDirective = __decorate([
        Directive({
            selector: '[ngxValidator]',
        }),
        __metadata("design:paramtypes", [TemplateRef,
            ViewContainerRef])
    ], NgxValidatorDirective);
    return NgxValidatorDirective;
}());

var ValidatableDirective = /** @class */ (function () {
    function ValidatableDirective() {
    }
    ValidatableDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        this.controls.forEach(function (control) {
            control.valueChanges.subscribe(function (data) {
                _this.toggleAllValidatorItems(control);
            });
        });
    };
    ValidatableDirective.prototype.toggleAllValidatorItems = function (control) {
        var _this = this;
        this.validatorItems.forEach(function (validatorItem) {
            if (validatorItem.validator) {
                _this.ToggleValidateItem(validatorItem, control);
            }
        });
    };
    ValidatableDirective.prototype.ngOnInit = function () {
    };
    ValidatableDirective.prototype.ToggleValidateItem = function (validatorItem, control) {
        if (control && control.dirty) {
            var error = control.getError(validatorItem.validator.toLowerCase());
            if (error) {
                validatorItem.showError(error);
            }
            else {
                validatorItem.hideErrors();
            }
        }
    };
    __decorate([
        ContentChildren(NgControl),
        __metadata("design:type", QueryList)
    ], ValidatableDirective.prototype, "controls", void 0);
    __decorate([
        ContentChildren(NgxValidatorDirective),
        __metadata("design:type", QueryList)
    ], ValidatableDirective.prototype, "validatorItems", void 0);
    ValidatableDirective = __decorate([
        Directive({
            selector: '[ngxValidatable]',
        }),
        __metadata("design:paramtypes", [])
    ], ValidatableDirective);
    return ValidatableDirective;
}());

var NgxValidateHelperModule = /** @class */ (function () {
    function NgxValidateHelperModule() {
    }
    NgxValidateHelperModule = __decorate([
        NgModule({
            declarations: [ValidatableDirective, NgxValidatorDirective],
            imports: [],
            exports: [ValidatableDirective, NgxValidatorDirective],
        })
    ], NgxValidateHelperModule);
    return NgxValidateHelperModule;
}());

/*
 * Public API Surface of ngx-validate-helper
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxValidateHelperModule, ValidatableDirective, NgxValidatorDirective as ɵa };
//# sourceMappingURL=ngx-validate-helper.js.map
